Welcome to the KAT Communication Protocol's documentation!
==========================================================

KATCP is a simple ASCII communication protocol layered on
top of TCP/IP.

It is developed as a part of the `Karoo Array Telescope <http://ska.ac.za/>`_
(KAT) project and used at KAT for the monitoring and control of hardware
devices.

The protocol specification :download:`NRF-KAT7-6.0-IFCE-002-Rev4.pdf`
is maintained as an internal memo. The latest version is `Rev4`.


Contents
========

.. toctree::
   :maxdepth: 2

   api
   txkatcp
   kattypes
   sampling
   tutorial

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

